@@ -19,6 +19,7 @@ __docformat__ = "restructuredtext en"
 
 import re
 
+from cubicweb import RegistryException
 from cubicweb.server import hook
 from cubicweb.selectors import is_instance, on_fire_transition
 from cubicweb.hooks import notification
@@ -147,20 +148,20 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                 if words[1] in ('ready', 'pending') and words[0] in readycandidates:
                     fire(readycandidates.pop(words[0]),
                          'ask review', u'review asked by %s in %s' % (
-                             rev.author, rev.changeset or rev.revision))
+                             rev.author, rev.dc_title()))
                 elif words[0] in ('refuse', 'refused') and words[1] in pendingcandidates:
                     patch = pendingcandidates.pop(words[1])
                     fire(patch, 'ask rework', u'refused by %s in %s' % (
-                        rev.author, rev.changeset or rev.revision))
+                        rev.author, rev.dc_title()))
                 elif words[0] in ('reject', 'rejected') and words[1] in rejectcandidates:
                     patch = rejectcandidates.pop(words[1])
                     fire(patch, 'reject', u'rejected by %s in %s' % (
-                        rev.author, rev.changeset or rev.revision))
+                        rev.author, rev.dc_title()))
                     self.ensure_wont_be_deleted(patch)
                 elif words[0] in ('fold', 'folded') and words[1] in rejectcandidates:
                     patch = rejectcandidates.pop(words[1])
                     fire(patch, 'fold', u'folded by %s in %s' % (
-                        rev.author, rev.changeset or rev.revision))
+                        rev.author, rev.dc_title()))
                     self.ensure_wont_be_deleted(patch)
                 elif words[0] in ('apply', 'applied') and words[1] in rejectcandidates:
                     patch = rejectcandidates.pop(words[1])
@@ -233,9 +234,13 @@ class ReviewerSetHook(hook.Hook):
     def __call__(self):
         # send notification
         rset = self._cw.eid_rset(self.eidfrom)
-        view = self._cw.vreg['views'].select(
-            'vcreview.notifications.reviewer-set', self._cw,
-            rset=rset, user=self._cw.eid_rset(self.eidto).get_entity(0, 0))
+        try:
+            view = self._cw.vreg['views'].select(
+                'vcreview.notifications.reviewer-set', self._cw,
+                rset=rset, user=self._cw.eid_rset(self.eidto).get_entity(0, 0))
+        except RegistryException:
+            # view unregistered or unselectable
+            return
         notification.RenderAndSendNotificationView(self._cw, view=view)
         # ensure user is in the nosy-list
         self._cw.execute('SET P nosy_list U WHERE P eid %(p)s, U eid %(u)s, NOT P nosy_list U',
