@@ -18,7 +18,7 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from yams.buildobjs import EntityType, RelationDefinition, String
+from yams.buildobjs import EntityType, RelationDefinition, String, Int
 
 from cubicweb.schema import WorkflowableEntityType, RQLConstraint, RRQLExpression
 
@@ -126,8 +126,8 @@ class patch_depends_on(RelationDefinition):
 # ability to reference diff chunks #############################################
 
 class InsertionPoint(EntityType):
-    __unique_together__ = [('id', 'point_of')]
-    id = String(maxsize=100, indexed=True)
+    __unique_together__ = [('lid', 'point_of')]
+    lid = Int(indexed=True, required=True)
 
 class point_of(RelationDefinition):
     subject = 'InsertionPoint'
