@@ -110,7 +110,7 @@ class PatchCreationHooksTC(CubicWebTC):
 
         self.assertTrue(patch3_2.nosy_list)
         self.assertEqual(len(MAILBOX), 3)
-        self.assertEqual(MAILBOX[0].subject, '[patch pending-review] patch3.diff (patch repository)')
+        self.assertEqual(MAILBOX[0].subject, '[patch repository] patch pending-review: patch3.diff')
         self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[0].content, u'''
 cubicweb changed status from <in-progress> to <pending-review> for entity
@@ -120,14 +120,14 @@ review asked by Sylvain Th\xe9nault <sylvain.thenault@logilab.fr> in 9cf50f15d9a
 
 url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
 
-        self.assertEqual(MAILBOX[1].subject, '[patch assigned] patch3.diff (patch repository)')
+        self.assertEqual(MAILBOX[1].subject, '[patch repository] patch assigned: patch3.diff')
         self.assertEqual(MAILBOX[1].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[1].content, u'''
 You have been assigned for review of patch patch3.diff
 
 url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
 
-        self.assertEqual(MAILBOX[2].subject, '[patch rejected] patch3.diff (patch repository)')
+        self.assertEqual(MAILBOX[2].subject, '[patch repository] patch rejected: patch3.diff')
         self.assertEqual(MAILBOX[2].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[2].content, u'''
 cubicweb changed status from <pending-review> to <rejected> for entity
@@ -143,7 +143,7 @@ url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
         done = req.create_entity('Task', title=u'done', reverse_has_activity=patch3_2)
         self.commit()
         self.assertEqual(len(MAILBOX), 2)
-        self.assertEqual(MAILBOX[1].subject, '[patch task] patch3.diff: done (patch repository)')
+        self.assertEqual(MAILBOX[1].subject, '[patch repository] patch task: patch3.diff - done')
         self.assertEqual(MAILBOX[1].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[1].content, u'''
 done
@@ -180,7 +180,7 @@ url: http://testing.fr/cubicweb/task/%s\n''' % done.eid)
         #self.assertEqual(patch3_2.applied_at[0].eid, patch3_2.revisions[-1].rev.eid) XXX
 
         self.assertEqual(len(MAILBOX), 1, MAILBOX)
-        self.assertEqual(MAILBOX[0].subject, '[patch applied] patch3.diff (patch repository)')
+        self.assertEqual(MAILBOX[0].subject, '[patch repository] patch applied: patch3.diff')
         self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[0].content, u'''
 admin changed status from <pending-review> to <applied> for entity
