@@ -29,7 +29,7 @@ _pvs = uicfg.primaryview_section
 _pvs.tag_object_of(('InsertionPoint', 'point_of', '*'), 'hidden')
 _abaa.tag_object_of(('InsertionPoint', 'point_of', '*'), False)
 _abaa.tag_subject_of(('InsertionPoint', 'has_activity', '*'), False)
-_affk.tag_attribute(('InsertionPoint', 'id'),
+_affk.tag_attribute(('InsertionPoint', 'lid'),
                     {'widget': wdg.HiddenInput})
 _affk.tag_subject_of(('InsertionPoint', 'point_of', '*'),
                      {'widget': wdg.HiddenInput})
