@@ -25,7 +25,7 @@ from cubicweb.selectors import score_entity, is_instance
 from cubicweb.view import EntityView
 from cubicweb.schema import display_name
 from cubicweb.web import uicfg
-from cubicweb.web.views import primary, ibreadcrumbs
+from cubicweb.web.views import tabs, primary, ibreadcrumbs
 
 from cubes.vcsfile.views import primary as vcsfile
 from cubes.vcreview.views import patch_states_rql
@@ -44,16 +44,24 @@ _pvs.tag_subject_of(('Patch', 'patch_revision', '*'), 'hidden') # table in attri
 _pvs.tag_subject_of(('Patch', 'patch_reviewer', '*'), 'attributes')
 _pvdc.tag_subject_of(('Patch', 'applied_at', '*'), {'vid': 'incontext'})
 
-class PatchPrimaryView(primary.PrimaryView):
-    __select__ = primary.PrimaryView.__select__ & is_instance('Patch')
+class PatchPrimaryView(tabs.TabbedPrimaryView):
+    __select__ = is_instance('Patch')
+
+    tabs = [_('vcreview.patch.tab_main'), _('vcreview.patch.tab_head')]
+    default_tab = 'vcreview.patch.tab_main'
 
     def render_entity_title(self, entity):
         self.w(u'<h1>%s <span class="state">[%s]</span></h1>'
                % (xml_escape(entity.dc_title()),
                   xml_escape(entity.cw_adapt_to('IWorkflowable').printable_state)))
 
+
+class PatchPrimaryTab(tabs.PrimaryTab):
+    __regid__ = 'vcreview.patch.tab_main'
+    __select__ = is_instance('Patch')
+
     def render_entity_attributes(self, entity):
-        super(PatchPrimaryView, self).render_entity_attributes(entity)
+        super(PatchPrimaryTab, self).render_entity_attributes(entity)
         self.w(u'<h4>%s</h4>' % self._cw._('Patch revisions'))
         rset = self._cw.execute(
             'Any VC,RA,RB,RC,RD,VC, R ORDERBY RC DESC '
@@ -68,6 +76,17 @@ class PatchPrimaryView(primary.PrimaryView):
                    cellvids={0: 'vcreview.fileversion',
                              5: 'vcreview.revcommentcount'})
 
+
+class PatchHeadTab(EntityView):
+    __regid__ = 'vcreview.patch.tab_head'
+    __select__ = is_instance('Patch')
+
+    def entity_call(self, entity):
+        tip = entity.tip()
+        if tip:
+            tip.view('primary', w=self.w)
+
+
 class DVCFileVersion(EntityView):
     __regid__ = 'vcreview.fileversion'
     __select__ = is_instance('DeletedVersionContent', 'VersionContent')
@@ -104,6 +123,12 @@ class VCPrimaryView(vcsfile.VCPrimaryView):
     __select__ = (vcsfile.VCPrimaryView.__select__
                   & score_entity(lambda x: x.patch))
 
+    def render_entity_title(self, entity):
+        title = self._cw._('Revision %(revision)s of patch %(file)s') % {
+            'revision': entity.revision, 'file': entity.patch.view('oneline')}
+        self.w('<h1>%s</h1>' % title)
+        vcsfile.render_entity_summary(self, entity)
+
     def render_entity_attributes(self, entity):
         # XXX have to call primary.PrimaryView directly to avoid duplicated display
         # of version's content
